---
title: "Morphological Evidence for the Coherence of East Sudanic"
authors: ["rogermblench.md"]
abstract: "East Sudanic is the largest and most complex branch of Nilo-Saharan. First mooted by Greenberg in 1950, who included seven branches, it was expanded in his 1963 publication to include Ama (Nyimang) and Temein and also Kuliak, not now considered part of East Sudanic. However, demonstrating the coherence of East Sudanic and justifying an internal structure for it have remained problematic. The only significant monograph on this topic is Bender's *The East Sudanic Languages,* which uses largely lexical evidence. Bender proposed a subdivision into Ek and En languages, based on pronouns. Most subsequent scholars have accepted his Ek cluster, consisting of Nubian, Nara, Ama, and Taman, but the En cluster (Surmic, E. Jebel, Temein, Daju, Nilotic) is harder to substantiate. Rilly has put forward strong arguments for the inclusion of the extinct Meroitic language as coordinate with Nubian. In the light of these difficulties, the paper explores the potential for morphology to provide evidence for the coherence of East Sudanic. The paper reviews its characteristic tripartite number-marking system, consisting of singulative, plurative, and an unmarked middle term. These are associated with specific segments, the singulative in *t-* and plurative in *k-* as well as a small set of other segments, characterized by complex allomorphy. These are well preserved in some branches, fragmentary in others, and seem to have vanished completely in the Ama group, leaving only traces now fossilized in Dinik stems. The paper concludes that East Sudanic does have a common morphological system, despite its internal lexical diversity. However, this data does not provide any evidence for the unity of the En languages, and it is therefore suggested that East Sudanic be analyzed as consisting of a core of four demonstrably related languages, and five parallel branches which have no internal hierarchy."
keywords: ["East Sudanic", "Nilo-Saharan", "comparative linguistics"]
---

# Introduction

The East (formerly “Eastern”) Sudanic languages, spread between Chad and Northern Tanzania, constitute a branch of Nilo-Saharan with a proposed membership of nine families, including Nilotic, the largest and most complex group. We owe the original concept of East Sudanic to Greenberg who attributed seven branches to it,[^1] shown in **Table 1**, together with their modern names. Families unknown to Greenberg are added in the “Current” column.

[^1]: Greenberg, "Studies in African Linguistic Classification: V. The Eastern Sudanic Family.”

| Greenberg (1950) | Current |
| :---             | :---     |
| Nubian           | Nubian + Meroitic |
| Beir-Didinga     | Surmic |
| Barea            | Nara |
| Tabi             | Eastern Jebel |
| Merarit          | Taman |
| Dagu             | Daju |
| Southern         | Nilotic |
|                  | Nyima  |
|                  | Temein |

**~~Table 1. Greenberg's original concept of East Sudanic~~**

Greenberg was not aware of Nyimang and Temein, and these were added later in Greenberg together with Kuliak,[^2] now considered by Bender to be a separate branch of Nilo-Saharan.[^3] Greenberg claimed East Sudanic was part of “Chari-Nile,” a group which included Central Sudanic, Kunama, and Bertha.[^4] Chari-Nile is also now not thought to be valid.[^5] Somewhat confusingly, Tucker had earlier published a book entitled *The Eastern Sudanic Languages* but it is largely about Central Sudanic, Ubangian, and Nilotic languages.[^6] Prior to Greenberg, many individual languages or small groups had been described in Tucker & Bryan, but they were not combined into a larger unit.[^7] Greenberg makes a large number of proposals for grammatical and lexical isomorphs, which more recent scholars have not followed up in detail.[^8]

[^2]: Greenberg, *The Languages of Africa.*
[^3]: Bender, *The Nilo-Saharan Languages.*
[^4]: Greenberg, *The Languages of Africa.*
[^5]: Bender, *The Nilo-Saharan Languages.*
[^6]: Tucker, *The Eastern Sudanic Languages, vol. 1.*
[^7]: Tucker & Bryan, *The Non-Bantu Languages of North-Eastern Africa.*
[^8]: Greenberg, “Studies in African Linguistic Classification: V. The Eastern Sudanic Family.”

East Sudanic languages are by far the most well-known branch of Nilo-Saharan, with Nilotic and Nubian the main focal points. This is undoubtedly a reflection of the cultural prominence of the speakers and their relative accessibility. However, rather like Bantu, Nilotic represents a recent expansion and is only a fragment of the internal diversity of Eastern Sudanic. Nubian has attracted researchers because of its old manuscript attestations and epigraphic tradition. It has long been suspected that the extinct Meroitic language is part of East Sudanic,[^9]  but the small number of unambiguously identified lexemes made this argument difficult to sustain. However, with the work of Rilly and Rilly & De Voogt this argument can be considered secure.[^10] Rilly places Meroitic as coordinate with proto-Nubian as part of his “Northern East Sudanic” family. **Map 1** shows their approximate distribution in recent times.

[^9]: E.g., “Meroitic and Eastern Sudanic: A Linguistic Relationship.”
[^10]: Rilly, *Le méroïtique et sa famille linguistique*; Rilly & De Voogt, *The Meroitic Language and Writing System.*

![The East Sudanic languages](../static/images/east-sudanic.jpg "The East Sudanic languages")

**~~Map 1. The East Sudanic languages~~**

The nine branches remain the accepted listing with some relatively minor reassignments. There have been few attempts to synthesise data on East Sudanic, the unpublished MSc thesis of Ross,[^12] who was a student of Bender, and Bender’s own studies and monograph.[^13] The study by Starostin of Nubian–Nara–Tama is part of a project to re-evaluate East Sudanic as a whole from the point of view of lexicostatistics.[^14] Bender gives basic phonologies representative of each branch, as well as an argument for the coherence of East Sudanic based principally on lexical evidence. This latter was locally printed in Carbondale and is best described as problematic to read for those who are not strongly motivated to penetrate its forest of acronyms and compressed citations. It has therefore had a very limited impact on Nilo-Saharan studies. However, it is full of interesting suggestions for isoglosses and presents an elaborate table of sound correspondences, so it undoubtedly merits close study. Unlike Bender’s Omotic compendium,[^15] it does not include original lexical forms systematically, and hence each entry needs to be rechecked against original and more current source data. It is safe to say Bender’s publications did not have a resounding impact on the scholarly community.

[^12]: Ross, *A Preliminary Attempt at the Reconstruction of Proto-East Sudanic Phonology and Lexicon.*
[^13]: Bender, “Genetic subgrouping of East Sudanic"; Bender, *The East Sudanic Languages.*
[^14]: Starostin, “Lexicostatistical Studies in East Sudanic I”; ![Starostin, this issue](article:starostin.md).
[^15]: Bender, *Comparative Omotic Lexicon.*

Despite its previous acceptance, the published arguments for the coherence of East Sudanic remain weak. No unambiguous innovations, lexical or phonological, mark all branches as members. Some researchers have expressed scepticism about its unity. However, studies of East Sudanic by Dimmendaal broadly accept the classification of Bender,[^16] although using very different criteria for accepting its coherence. However, Güldemann remains sceptical, arguing that internal typological differences may be evidence for convergence rather than genetic affiliation.[^16a] The [Glottolog](https://glottolog.org/) takes a far more extreme position, treating all branches as distinct families.

[^16]: Dimmendaal, “Differential Object Marking in Nilo-Saharan"; Dimmendaal, *Historical Linguistics and the Comparative Study of African Languages*; Dimmendaal, "Marked Nominative Systems in Eastern Sudanic and Their Historical Origin.”
[^16a]: Güldemann, “The Historical-Comparative Status of East Sudanic.”

# Lexical evidence

## East Sudanic as a Unity

Claims for the reality of East Sudanic are largely based on lexical evidence. Bender proposes the most significant set of proposals in this area,[^101] but Greenberg’s original argument also includes some suggestions. Assuming the coherence of East Sudanic, the proposals for an internal structure are tenuous. Bender has argued in various places that East Sudanic has two main subdivisions, which he notates Ek and En, on the basis of the first person independent pronoun (**Table 2**).[^102]

[^101]: Bender, *The East Sudanic Languages.*
[^102]: Ibid.; Bender, *The Nilo-Saharan Languages.*

| Ek  | Branch | En  | Branch |
| :--- | :---    | :--- | :--- |
| E1  | Nubian | E2  | Surmic |
| E3  | Nara   | E4  | Eastern Jebel |
| E5  | Nyima    | E6  | Temein(?) |
| E7  | Taman  | E8  | Daju |
|     |        | E9  | Nilotic |

**~~Table 2. Bender’s subclassification of East Sudanic~~**

The first person singular subject pronoun in East Sudanic, first set out by Greenberg and later supplemented by Bender, forms a distinctive set (**Table 3**):

| Branch        | Language(s) | Form |
| :---           | :---         | :--- |
| Nubian        | Nobiin      | ay |
| Nara          | Nara        | ag |
| Nyima         | Ama         | a(i) |
| Taman         | All         | wa, wo |
| Surmic        | Didinga     | a |
| Surmic        | Kwegu       | aan |
| Eastern Jebel | Gaahmg      | aan |
| Temein        | Ronge       | nan |
| Daju          | Nyala       | aaga |
| West Nilotic  | Dinka       | an |
| East Nilotic  | Masai, Turkana, Nandi, Teso | nanu |
| South Nilotic | Pokot       | anii |

**~~Table 3. First person singular subject pronoun in East Sudani[^103]~~**

[^103]: Data from Bender, “The Genetic Position of Nilotic *i*” and Bender, *The East Sudanic Languages,* supplemented with more recent sources.

Even this dataset does not entirely support Bender’s division, since Daju appears to fall in the Ek group. The forms with a nasal largely correspond to Bender’s En, while those without nasals correspond to Ek. However, on this evidence, the presence of a velar cannot be said to characterise all Ek languages.

## The Ek Languages

Bender, Ehret, Rilly, and Starostin agree that at least Nubian, Nara, Tama, and perhaps Nyimang form a subgroup (Ehret’s “Astaboran”).[^104] The lexical tables below provide a summary version of the compilations of Rilly sometimes with updated citations. **Table 4** shows the Ek forms for “drink” which seem to refer to a protoform *\*dii*.

[^104]: Bender, *The Nilo-Saharan Languages*; Bender, *The East Sudanic Languages*; Ehret, *A Historical-Comparative Reconstruction of Nilo-Saharan*; Rilly, *Le méroïtique et sa famille linguistique*, and Starostin, "Lexicostatistical Studies in East Sudanic I.”

| Subgroup | Language   | Attestation |
| :---     | :---       | :---        |
| Nara     |        | líí         |
| Nubian   | Dilling    | di          |
| Nubian   | Midob     | tìì         |
| Nyima    | Ama        | lì          |
| Taman    | Proto-Taman | \*li(y)-    |

**~~Table 4. Ek lexical isogloss, “drink,” *\*dii*[^t4]~~**

[^t4]: Nara and Ama data from Rilly, *Le méroïtique et sa famille linguistique*; Dilling, Midob, and proto-Taman data from Starostin, "Lexicostatistical Studies in East Sudanic I.”

**Table 5** shows a common form for “house,” assuming Nubian preserves a velar lost in the other languages. The vowel is not entirely clear, but I provisionally reconstruct a mid central vowel.

| Subgroup  | Language | Attestation |
| :---      | :---     | :---        |
| Nubian    | Midob    | kàr         |
| Nubian    | Nyala    | aare        |
| Nara      |      | wǒl         |
| Nyima     | Ama      | wel         |
| Taman      | Tama     | wal         |

**~~Table 5. Ek lexical isogloss, “house,” *\*kəl*[^t5]~~**

[^t5]: Midob data from Werner, *Tìdn-áal*; Nyala data from Thelwall, “Birgid Vocabulary List and Its Links with Daju”; Nara data from Hayward, “Observations on Tone in the Higir Dialect of Nara”; Ama data from Bender, “Roland Stevenson’s Nyimang and Dinik Lexicon”; Tama data from Edgar, “First Steps toward Proto-Tama.”

*Table 6* shows a lexical isogloss for “mouth,” *\*aŋəl.* However, the Eastern Jebel language Gaamhg also appears to be either cognate or else a loan, so this constitutes slightly imperfect evidence.

| Subgroup  | Language   | Attestation |
| :---      | :---       | :---        |
| Nubian    | Andaandi   | agil        |
| Nara      |            |  aùlò       |
| Nyima     | Ama        | ŋàl         |
| Taman     | Abu Sharib | awl         |
| E Jebel   | Gaahmg     | ag          |

**~~Table 6. Ek lexical isogloss, “mouth,” *\*aŋəl*[^t6]~~**

[^t6]: Andaandi, Nara, and Abu Sharib data from Rilly, *Le méroïtique et sa famille linguistique*; Ama data from Bender, “Roland Stevenson’s Nyimang and Dinik Lexicon”; Gaahmg data from Stirtz, *A Grammar of Gaahmg*.

**Table 7** presents the evidence for the lexical isogloss, “two,” perhaps *\*wari(m)* if the *-m* in Nyima is to be included.

| Subgroup  | Language        | Attestation |
| :---      | :---            | :---        |
| Nubian    | Haraza          | auri-yah    |
| Nubian    | Old Nubian      | uwo         |
| Nubian    | Karko           | ārè         |
| Nara      |                 | ari-ga      |
| Nyima     | Proto-Nyima     | \*arm-      |
| Taman     | Proto-Taman     | \*wari      |

**~~Table 7. Ek lexical isogloss, “two,” *\*wari(m)*[^t7]~~**

[^t7]: Haraza data from Bell, "Documentary Evidence on the Ḥarāza Nubian,” 84; Old Nubian data from Browne, *Old Nubian Dictionary,* 138; Karko data from Jakobi & Hamdan, "Number Marking on Karko Nouns"; Nara data from Hayward, “Observations on Tone in the Higir Dialect of Nara”; Proto-Nyima data from Bender, “Roland Stevenson’s Nyimang and Dinik Lexicon”; Proto-Taman data from Edgar, “First Steps toward Proto-Tama.”

## The En Languages

Though the En languages share overlapping isoglosses, they do not share enough common material to be conclusively considered a genetic unity. Bender recognizes that the arguments for membership of Temein in his En group are sketchy. **Table 8** presents one of Bender’s better common glosses.

| Subgroup  | Language        | Attestation |
| :---      | :---            | :---        |
| Surmic    | Murle           | **ɓɔ**lɔ́ɔ́k |
| E Jebel   | Aka             | **bəəb**a |
| Temein    | Temein          | **pɔ̀p**áʈɪ̀ʈ |
| Daju      | Liguri          | ku**ɓu**du |
| E Nilotic | Lopit           | a.**bob**.io |
| E Nilotic | Maa             | a.**bob**.oki |

**~~Table 8. En lexical isogloss, “bark n.,” *\*-bob-*~~**

# Morphological Evidence

In the light of these problems with the lexicon, it may be that a better case for East Sudanic can be made on the basis of morphology. Bryan had already noted the existence of a “t-k substratum” in a variety of languages across East-Central Africa.[^301] These elements are affixes on nominals associated with number marking. Her argument is somewhat confused, as this feature is unlikely to be a substrate feature of some lost phylum. Most plausibly, it is a feature of Nilo-Saharan which has been borrowed *into* Afroasiatic (since it is definitely not a widespread feature of Afroasiatic). Bryan identifies the following morphological elements:

[^301]:  Bryan, “The T–K Languages.”

* Singulative *-t*
* Plural *-k*
* Plural -N

The majority of languages she uses to exemplify this principle would now be classified as East Sudanic. Greenberg calls moveable *k-* a “stage III article”[^302] while Ehret calls it both an “adjective suffix” and a “noun particularizing prefix.”[^303] Bender, who considers it a “noun-class formative remnant,”[^304] notes that it is widespread but not universal in Nilo-Saharan. Also included are some Cushitic languages, but the extension of the “substratum” is somewhat strained. The T-affix in Afroasiatic is a widespread marker of feminine gender and a deep level connection with Nilo-Saharan through semantic shift is not impossible. Bender also discusses N-affixes in Nilo-Saharan,[^305] reprising observations by Tucker & Bryan.[^306] Storch also takes up the issue of N/K and T/K alternations in relation to Nilotic noun morphology.[^307]

These affixes are certainly present in East Sudanic languages along with others. Many languages also permit gemination or consonant doubling. The origins of gemination in suffixes remains in doubt, but may arise from resuffixing, just as long consonants in Niger-Congo can arise from reprefixing in noun class languages. Moreover, nominals in East Sudanic can allow “affix-stacking,” the addition in sequence of one or more affixes as part of historical stratification.

The paper considers each branch of East Sudanic in turn, and briefly lays out the evidence for the affix system, as well as the presence of gemination and stacking. Discussion of the membership of individual branches, and their structure is not given here, but can be consulted in standard references.[^308]

[^302]: Greenberg, “Nilo-Saharan Moveable-*k* as a Stage III Article.”
[^303]: Ehret, *A Historical-Comparative Reconstruction of Nilo-Saharan,* pp. 176, 181.
[^304]: Bender, *The Nilo-Saharan Languages,* p. 75.
[^305]: Ibid.
[^306]: Tucker & Bryan, *Linguistic Analyses,* pp. 22–24.
[^307]: Storch, *The Noun Morphology of Western Nilotic,* p. 46.
[^308]: See Bender, *The Nilo-Saharan Languages* and the 2020 edition of [*Ethnologue*](https://www.ethnologue.com/).

# Individual Branches

## Nubian and Meroitic

Nubian demonstrates strong evidence for tripartite number marking in nouns. Jakobi & Hamdan describe Karko, which has a restricted system of suffixed singulatives, where *-Vt* and *-ɖ* are allomorphs (**Table 9**).

| Gloss          | [sg]({sc})      | [pl]({sc}) |
| :---           | :---     | :--- |
| sorghum        | wèê-t    | wèè |
| hair           | ʈēɽ-ét   | tèèl |
| bulrush millet | ɛ̀nɖ-ɛ́t   | ɛ̀nɖ |
| tooth          | jíl-ɖ    | jīīl |
| breast         | ə̄l-ɖ     | ɔ̄ɔ̄l |

**~~Table 9. Karko singulatives[^401]~~**

[^401]: Data from Jakobi & Hamdan, "Number Marking on Karko Nouns.”

However, the majority of suffixes denote plurals (**Table 10**). The majority seem to be allomorphs of the singulative suffix, thus *ɖ ~ Vl ~ Vr,* with a distinct second set, *Vɲ  ~ Vŋ*. The suffix *-Vnd* may be a composite of the nasal and alveo-dental suffixes.

| Gloss          | [sg]({sc})      | [pl]({sc}) |
| :---           | :---     | :--- |
| body           | íìl      | īl-ɖ |
| heart          | áàl      | āl-ɖ |
| star           | ōnɖ      | ōnɖ-ôl |
| milk           | éèj      | ēj-ēl |
| chicken        | kòk      | kōk-ôr |
| cat            | bùt      | bùt-ùr |
| | | |
| blood          | ōg       | ōg-ōnd |
| fire           | úk       | ūk-ūnd |
| | | |
| river          | ìr       | īr-īɲ |
| rope           | ə̀r       | ə̄r-ə̄ɲ |
| shield         | kə̀r      | kə̀r-ə̀ŋ |
| ostrich        | ʈùlɖ     | ʈùlɖ-ùŋ |

**~~Table 10. Karko plural marking[^401a]~~**

[^401a]: Data from Jakobi & Hamdan, "Number Marking on Karko Nouns.”

Proto-Nubian may have had a fully functional tripartite system, which has now eroded leaving both singulatives and plurals, but not simultaneously. Once allomorphy is taken into account, the available affixes are very restricted. A language such as Midob has a still more reduced system, with only the alveo-dental *t ~ di* (**Table 11**).

| Gloss    | [sg]({sc})      | [pl]({sc}) |
| :---     | :---     | :--- |
| thing    | sáar     | sàartì |
| house    | ə̀d       | ə̀ttì |
| child    | úccí     | ùccédí |
| woman    | íddí     | ìddédí |
| cow      | tə̀ə      | tə̀yítì |

**~~Table 11. Midob nominal plurals[^402]~~**

[^402]: Data from Werner, *Tìdn-áal*.

The restricted corpus for Meroitic and the absence of reliable grammatical information makes it problematic to know the nature of its affix system. However, a couple of glosses which are considered reliable almost certainly show singulatives comparable to other Nubian languages:

| Gloss    | Transliteration | Approx. pronunciation |
| :---     | :---            | :--- |
| sister   | *kdise, kdite*  | kaɖiɕ, kaɖit |
| life     | *pwrite*        | bawarit |

**~~Table 12. Meroitic glosses showing singulative marking[^403]~~**

[^403]: Data from Rilly, *Le méroïtique et sa famille linguistique*

## Nara

Nominal plurals in Nara are created through suffixing and sporadic gemination of the final consonant. The six plural classes are shown in **Table 13**. There are weak correlations with semantics and these are given only as indicative:

| Suffix |      | Gloss       | [sg]({sc})          | [pl]({sc})         | Semantics |
| :---   | :--- | :---        | :---         | :---        | :--- |
| -ka    | -K   | fox         | kerfe        | kerefka     | animals |
|        |      | animal      | oof          | oofka       | |
| -ta    | -T   | heart       | asma         | asimta      | body parts|
|        |      | meat        | nooti        | noota       | |
| -a     | -V   | ear         | tus          | tusa        | animals and plants |
|        |      | thorn       | keer         | keera       | |
| -tta   | -T   | blood       | kito         | kitotta     | collectives(?) |
|        |      | grass       | sum          | sumitta     | |
| -CCa   | -I   | bride       | solobi       | solobba     | people, animals |
|        |      | goat        | bele         | bella       | |
| -ʤʤa   | -S   | gland       | foʤi         | foʤʤaa      | internal secretions |
|        |      | milk course | ngiʤi        | ngiʤʤaa     | |

**~~Table 13. Nara number marking in nouns[^404]~~**

The plurals in last three classes which involve consonant doubling and change the final vowel to *-a* may simply be allomorphs of an underlying *-a* suffix. These may derive from a single rule and thus not exemplify the characteristic East Sudanic suffixes.

[^404]: Data from Dawd & Hayward, "Nara.”

## Nyima

Nyima covers two related languages, Nyimang and Afitti, now usually known as Ama and Dinik respectively. Both languages have retained only traces of the complex noun morphology characteristic of other East Sudanic branches. Ama nouns have a single plural-marking suffix, *-ŋi* (or *-gi* after a liquid). Even this is dropped when number can be inferred from either a numeral or a quantifier. There are a small number of suppletives for persons:

| Gloss              | [sg]({sc})      | [pl]({sc}) |
| :---               | :---     | :--- |
| person, [pl]({sc}) people | wodáŋ    | wàá |
| child              | wodéŋ    | ɖúriŋ |

**~~Table 14. Suppletive plural forms in Ama~~**

Reduplication can be used to express collectives, e.g., *ɖàmì* "egg"; *ɖàɖàmì* "all the eggs.”

Otherwise the loss of most plural marking is very marked in comparison with related branches. For Dinik, De Voogt notes number marking briefly, which he states is only applied consistently to animates. Dinik has three plural markers, *-gòr, -ná,* and *-é.*[^999] A comparison of the lexicon of Dinik yields some possible evidence for fossil affixes. Dinik in particular has a wide range of nominals with *-Vk* suffixes (**Table 14**).

[^999]: De Voogt, “Dual Marking and Kinship Terms in Afitti.”

| Gloss              | Attestation |
| :---               | :---        |
| river              | kwɔlək |
| dura sorghum       | mənək |
| scorpion           | ŋwunək |
| grave              | tirik |
| lightning          | arsək |
| salt               | ɔrdik |
| spear              | mətsək |

**~~Table 15. The fossil affix _-Vk_ in Dinik[^405]~~**

[^405]: Data from Bender, “Roland Stevenson’s Nyimang and Dinik Lexicon.”

Despite their lexical affinity to the Ek branch, Nyima languages have all but lost their indicative noun morphology. However, as Norton observes,[^a6] the characteristic *t/k* alternations are well preserved in the verbal system in the distinction between factative and progressive. **Table 16** exemplifies this alternation.

[^a6]: Norton, "Number in Ama Verbs"; ![Norton, this issue](article:norton.md).

| Gloss        | Factative        | Progressive |
| :---         | :---             | :--- |
| build        | t̪-ùɡ-è           | k-ūɡ |
| dig          | t̪-īw-ò           | k-íw |
| light (fire) | t̪-ūɕ-ē           | k-úɕ-ín |
| build        | tuɡɛ̀             | kwò |
| chop         | tàiɔ̀             | kaì |
| dig          | tìwò             | kìù  |

**~~Table 16. T/K marking on Ama verb stems[^t16]~~**

[^t16]: Data from ![Norton, this issue](article:norton.md)

Norton has a lengthy argument about how the nominal alternation became attached to verbs, which he summarises as follows:

> I therefore propose that this class of verbs attests the Nyima cognate of the wider Nilo-Saharan T/K alternation. This entails a chain of events in which the T/K alternation first moved from the noun (singular/plural) to the verb (singulactional/pluractional), and then shifted in meaning from verbal number to verbal aspect (factative/progressive) […]. Seen in this light, the significance of moving T/K morphology onto verbs in the Nyima branch is that it renewed an existing system of irregular singulactional/pluractional alternations.[^998]

[^998]: ![Norton, this issue](article:norton.md)

This shift from the nominal to the verbal system suggests that Nyima need no longer be treated as the missing piece in the puzzle of East Sudanic morphology.

## Taman

Descriptions of the morphology of Taman languages are very limited. Kellermann provides a summary of number marking in nouns, based on the manuscript material of Stevenson (**Table 17**):

| Affix   | [sg]({sc})      |  Affix      | [pl]({sc})           | Gloss |
| :---    | :---    |  :---        | :---       | :---  |
| -t      | mèya-t    |      -k    | mèya-k     | blacksmith |
| -t      |  wɪ̀gɪ-t      |  -ɛ     | wɪ̀gɪ-ɛ     | bird |
| -V      | áunyò    |     -(V)k   | áunyò-k    | elbow |
| -∅      | gaan   |       -(V)k    | gaan-ɪk    | tree |
| -∅      |    wal   |    -V       | wal-u      | house |
| -k      |   taɽ-ak    | -V        | taɽ-o      | chief |
| -X      |   iɲ-o   |    -(V)ɲ    | iɲ-iɲ      | pot |
| -∅      |  áwór |      -(V)ŋ     | áwór-oŋ    | knee |

**~~Table 17. Tama nominal number-marking[^407]~~**

[^407]: Data from Kellermann, *Eine grammatische Skizze des Tama auf der Basis der Daten von R.C. Stevenson.*

As with other East Sudanic languages, once allomorphy is taken into account, number-marking affixes are quite reduced. Tama has *-t, -k,* *-(V)N,* and an underspecified vowel. No examples of synchronic tripartite number marking are given, but the use of *-t* in the singulative and the “moveable” *-k* all point to this as formerly operative. The underspecified *V* in *-VC* suffixes suggests compounding, as in other East Sudanic languages.

## Surmic

Surmic displays abundant evidence for three-term number marking. **Table 18** shows its operation in Laarim:

| Gloss      | [sg]({sc})       | Generic       | [pl]({sc}) |
| :---       | :---      | :---          | :--- |
| gazelle    | boronit   | boron-        | boronua |
| nail       | gurmaloʧ  | gurmal-       | gurmaleeta |

**~~Table 18. Tripartite number marking in Laarim[^t18]~~**

[^t18]: Data from Joseph et al., *Laarim Grammar Book.*

Yigezu & Dimmendaal focus on Baale and **Table 19** shows its number marking system and identifiable affixes. The variability in Baale is extremely high with many minor differences, so the analysis is not always certain. For example, "stomach” might represent an original *-NV* affix, eroded by the subsequent addition of the *-TV.*

| Gloss | Affix   | [sg]({sc})      |  Affix  | [pl]({sc})       |
| :---    | :---     |  :---   | :---      | :---  |
| arm, hand | -∅      | ayí      | -NV     | ayinná    |
| moon | -∅      | ɲʊlʊ́     | -KV     | ɲɔlɔgɛ́    |
| man, person | -∅      | éé       | -TV     | eet̤á       |
| goat | -∅      | ɛ́ɛ́s      | -TV     | ɛ́ɛ́ta       |
| head | -A      | ɔwá      | -TV     | ooti       |
| face, forehead | -A      | ŋʊmmá    | -TV     | ŋuundí  |  
| stomach | -A      | kɛŋŋá    | -TV     | keendi    |
| ear | -NV     | ɪtááni   | -NV     | ɪnná      |
| rope | -S      | mɔssájí  | -N      | mɔɔssɛ́n   |


**~~Table 19. Baale number marking and affixes[^t19]~~**

[^t19]: Data from Yigezu & Dimmendaal, “Notes on Baale.”

From this evidence, Baale has singulars in *-(N)A,* *-S,* and *-NV* and plurals with *-KV, -TV,* and *-N.*

## Eastern Jebel

To judge by the data in Bender,[^410] Aka has a richer system of number marking than Gaahmg. Extracting the affixes from the system of number-marking, the following (at least) occur (**Table 20**):

[^410]: Bender, “The Eastern Jebel Languages of Sudan I”; Bender, "The Eastern Jebel Languages of Sudan II.”

| Gloss | Affix   | [sg]({sc})      |  Affix  | [pl]({sc})        |
| :---    | :---     |  :---   | :---      | :---  |
| tongue | -∅      | kala     | -A, -T  | kala.ati   |
| knee | -∅      | kʊsu     | -N      | kʊsuu.ŋi  |
| belly | -∅      | ɛllɛ     | -T      | ɛllɛ.ti   |
| ear | -∅      | sigii    | -T      | sigii.de   |
| fish | -∅      | ʔʊʊgu    | -T      | ʔʊʊgu.ði  |
| dog | -∅      | kɛle     | -V      | kɛle.i    |
| bone | -K      | gamoo.ka | -N      | gamoo.ɲi   |
| egg  | -K      | ʔʊmuu.ke | -T      | ʊʊmʊ.ti   |
| horn | -K      | kɔsʊl.ge | -V      | kɔsʊʊl.i   |
| cloud | -V      | aabuga   | -T      | aabug.adi |

**~~Table 20. Examples of Aka number marking on nouns[^t20]~~**

[^t20]: Data from Bender, “Proto-Koman Phonology and Lexicon.”

As with Gaamhg, nouns can have zero marking, singulatives a velar or underspecified vowel, with plural affixes *-Ti, -Ni,* or a single vowel. Some plural suffixes, such as *-aTi,* probably combine two affixes, a pattern found elsewhere in East Sudanic.

## Temein

Temein consists of three languages, Temein, Keiga Jirru, and These.[^412] Surface forms for number marking in Temein are highly diverse and not easy to predict, even though the basic elements are relatively few. Temein languages operate a three-way system of number-marking with an unmarked form plus singulatives and pluratives, also known as “replacive.”[^413] However, the erosion of this system has meant that nouns where three terms occur synchronically are relatively rare. **Table 21** shows some examples of these:

[^412]:  Blench, “Introduction to the Temein Languages.”
[^413]:  See, e.g., Dimmendaal, “Number Marking and Noun Categorization in Nilo-Saharan Languages,” or Blench, “Introduction to the Temein Languages.”

Language    | Gloss      | [sg]({sc})                    | Unmarked                | [pl]({sc})      |
| :---      | :---       | :---                   | :---                    | :---  |
Temein      | dura       | mórɪŋɪnʈɛʈ (one grain) | mórɪŋɪs (head of grain) | mórɪŋ (dura plant) |
Keiga Jirru | meat       | bɪlanḑàk (one piece)   | ɪnɖàk                   | kɪnɖaɖɪ̀k |
Keiga Jirru | medicine   | móreḑàk                |                         | komórò (roots) |
These       | fat (n.)   | nányɛ́ɖə̀k               | nányàʔ                  | kɪnányàʔ |

**~~Table 21. Tripartite number marking in the Temein cluster~~**

Number marking in Temein displays typical Nilo-Saharan characteristics, although these are combined in ways that are difficult to predict for individual nouns. The most common elements are:

* “Moveable k-” (with an underspecified vowel), prefixed, suffixed or both, where prefixed *kV-* is a typical strategy for Arabic loanwords
* Addition of final *–NI*
* Addition of final *–a[ʔ]*
* Singulative marking with *–Iʈ,* *-Is*
* Vowel lengthening and unpredictable changes in vowel quality
* Changes in ATR quality of the vowel
* Suppletion is present although not always easy to identify due to vowel changes and shortening

### Prefix *k-*

In the Temein cluster *k-* is strongly associated with plurals and can occur before, after, and at both ends of a word. The underspecified vowel often results in a copy of the stem vowel, though not in every case. The vowel can disappear when the stem begins with an approximant. *Table 22* shows surface forms in Temein:

| Gloss       | Unmarked  | [pl]({sc})     |
| :---        | :---      | :---    |
| belly       | óòm       | kómɪk |
| big         | ḿbù       | kɪmbɪk |
| hill, stone | kúrɛʈ     | kukúrɛʈ |
| shield      | wór       | kwòráʔ |

**~~Table 22. Temein *-Vk, kV-* nominal affixes~~**

This affix has an allomorph *–Vk* that can mark singulative as in These (**Table 23**):

| Gloss       | [sg]({sc})      | Unmarked     |
| :---        | :---      | :---    |
| firewood    | márɛnyɪk  | márɛŋ |
| ear         | ŋwánɪk    | kwɛɛŋ |
| eye         | náánɪk    | kɛnyɪŋ |
| fish        | kɛlɛɖak   | káála |

**~~Table 23. These *-Vk* singulative affix~~**

In the case of the singulative for “fish,” it appears that it has already been marked once as a singulative with *–ʈ* and the *–Vk* has been subsequently affixed.

### Final *–NI*

Less common is *–NI* or *-IN* in final position. Temein examples are shown in **Table 24**:

| Gloss       | Unmarked  | [pl]({sc})     |
| :---        | :---      | :---    |
| friend      | wórɪnyà   | kórɪnyànɪ̀ |
| hanging frame | sɛsɪlàŋ | sɛsɪlàŋì |
| moon        | kóù        | kikówɪn |

**~~Table 24. Temein -IN, -NI plural affix~~**

The following affixes can thus be attributed to Temein, *-T, -K, -N, -S, -V.* Temein shows no evidence for consonant gemination.

## Daju

Daju languages also show evidence for the characteristic three-way number-marking contrast of Nilo-Saharan, albeit realised in a fragmentary way in many languages. Stevenson describes the three-way contrast in Shatt Tebeldia:

> Many nouns have three forms, representing mass or collective / unit / units. [...] The suffix is then replaced by another, or a further suffix is added, to denote the plural of the unit. [...][^414]

[^414]:  Stevenson, “A Survey of the Phonetics and Grammatical Structures of the Nuba Mountain Languages,” 96.

This is shown for two glosses in **Table 25**:

| Gloss       | [sg]({sc})      | Unmarked     | [pl]({sc}) (countable) |
| :---        | :---      | :---         | :--- |
| egg         | gilis-ic  | gilis        | gilis-u
| worm        | ox-uic    | ox           | ox-uij-iny |

Shatt and Laggori at least have considerable diversity of surface affixes marking number, either singulative or plural with suffixes as well as replacing word endings.[^415] Boyeldieu describes the number marking in Shatt Damman in some detail (**Table 26**).

[^415]: Boyeldieu, *La qualification dans les langues africaines*; Alamin Mubarak, “An Initial Description of Laggori Noun Morphology and Noun Phrase.”

| Category            | [sg]({sc})      | [pl]({sc})   |
| :---                | :---     | :---  |
| [sg]({sc})/pl. alternation | -V       | -u |
|                     | -x       | -ɲ |
|                     | -c       | -ɲ, or -ic / -iɲ, or -d(d)ic / -d(d)iɲ |
|                     | -ic      | -u |
|                     | -(ɨ)c    | -ta/-d(d)a |
| [pl]({sc}) only            |          | -iɲ |
|                     |          | -u |
|                     |          | -ta/-d(d)a |
|                     |          | -ti/-d(d)i |
|                     |          | -tiɲ |
|                     |          | -dɨk |
| [sg]({sc}) only            | -ic | |
|                     | -tic/-d(d)ic | |
|                     | -c | |
|                     | -sɨnic/-zɨnɨc | |

**~~Table 26. Number-marking suffixes in Shatt Damman[^t26]~~**

[^t26]: Data from Boyeldieu, *La qualification dans les langues africaines.*

Boyeldieu also lists a significant number of irregular forms. There are three classes of noun, those with alternation, and those with singulatives and those with plurals. It appears there are now no examples of three-way contrast. Despite the surface variety, allomorphy suggests there are five underlying affixes, *-N, -T, -K, -y,* and *-V* where *V* is a high back vowel. In addition, the *-x* suffix may an allophone of an underlying fricative, i.e., *-S* (*s ~ z*), which would give Daju a complete set of East Sudanic affixes. Some singulative suffixes, such as *-zɨnɨc,* illustrate multiple compounding. There are, however, no examples of gemination.

The alternating nominal suffixes of Dar Daju described by Aviles present a far simpler set.[^417] Every noun has one of four singular suffixes. Aviles calls these “classificatory” although they have no obvious semantic association. These alternate with four plural suffixes, although these all appear to be allomorphs of *-ge* (**Table 27**).

[^417]: Aviles, *The Phonology and Morphology of the Dar Daju Daju Language.*

| Class | Gloss     | [sg]({sc})      |
| :---  | :---      | :---     |
| 1     | elder     | ɉam-ne |
| 2     | liver     | cacaw-ce |
| 3     | mouth     | uk-e |
| 4     | car       | watiɾ-i |

**~~Table 27. Singulative suffixes in Dar Daju[^t27]~~**

[^t27]: Data from Aviles, *The Phonology and Morphology of the Dar Daju Daju Language.*

The singulative suffixes *-NV, -ʧV,* and *-V* (where *V* is a front vowel) can be attributed to Dar Daju.

## Nilotic

### West Nilotic

The principal overview of noun morphology in West Nilotic is presented by Storch. Western Nilotic also has an emergent classifier system, described in some detail in Storch but omitted here. **Table 28** summarizes the affixes of West Nilotic:

| Semantics | Mayak | Mabaan | Jumjum | Dinka | Nuer | Anywa | Päri |
| :--- | :--- | :--- | :--- | :--- | :--- | :--- | :--- |
| general | -(V)k | -k(ʌ̃) | -kV | -k, -V |  | -k, -Ci, Cè | -ki, -ke |
| general | -(V)n | -Cin̪ | -ni | -N, -V | -ní, -V̪ | -Ci?, -Cè?  | -Neʔ |
| round, mass, small | | -ǎn̪ | | | | -i | -e  |
| body | | -kù | | | -c | -Ci | -ì  |
| space| |  | | | (\*-N?) | |  |
| unspecified | | -λ | | | -y | -è |  |
| unspecified | -it̪ | -t̪ǎn |  | -t̪ | -t̪ | -t, -Cè  | -rí, -te |
| -ḓín | | | | | | |

| Semantics | Shilluk | Lüwo | Thuri | Belanda Bor | S. Lwoo | Labwor |
| :--- | :--- | :--- | :--- | :--- | :--- | :--- |
| general | \*-k | -kʌ̀ | -k |  | -k(V), -ke | -gV |
| general | -V(N) | -V, -ɛ, -NVɛ́ | -Ni, -in, -Nɛ́, -ɛ́n |  | -ni, -n(í)n, -ne | -ni, -né |
| round, mass, small | (.ˋ), (ʾ) | -ɛ́ | -ɛ́ | | -e | -é, i |
| body |  | -ì | -ì | | -i | -i |
| space|  | |  | | |   |
| unspecified | [.ˋ] | | | |  |  |
| unspecified | -Vdi | -t̪ | -d̪i | | \*-ti, -(t)àʔ | -(C)áʔ |
| abstract| | | | | |  |

**~~Table 28. Number marking affixes in West Nilotic[^418]~~**

If we presume the same processes of allomorphy as elsewhere in East Sudanic, the number marking affixes of Proto-West Nilotic can be summarized more briefly:

* Underlying affixes: *-KV, -TV, -NV, -V*
* Compound affixes: *-TVN, -VTV, -VNV*

[^418]: Data from Storch, *The Noun Morphology of Western Nilotic,* 385.

### East Nilotic

The only survey of East Nilotic lexicon remains Voßen's,[^419] and this can provide an impression of number marking morphology, although descriptions of individual languages provide more detail. For example, Kuku has unmarked nominals, with singulatives in some cases, and plurals, both suffixed. **Table 29** shows examples of the main number-marking strategies in Kuku.

[^419]: Voßen, *The Eastern Nilotes.*

| Gloss       | Affix    | [sg]({sc})        |  Affix    | [pl]({sc})   |
| :---        | :---     |  :---      | :---      | :---  |
| cattle tick | -T(T)    | mɨ́sɨ́r.ɨtɨ́t | -∅        | másɛ̂r |
| black ant   | -T       | múkúɲ.êt   | -∅        | múkûn |
| Bari        | -N + -T  | bari.nɪ́t   | -∅        | barɪ |
| hippo       | -∅       | yárɔ́       | -S + -N   | yárɔ́.Ɉɪn |
| school      | -∅       | sukúlu     | -K        | sukúlu.kíʔ |
| nose        | -∅       | kʊmɛ́       | -S        | kʊmɛ́.sɪʔ |
| cheek       | -∅       | ŋɛ́bɪ́       | -T        | ŋɛ́bɪ́.at |
| speck       | -∅       | bɛ́rɛt      | -N        | bɛ́rɛt.án |
| hedgehog    | -∅       | leɲɨpúɗut  | -T + -M   | leɲɨpúɗu(t)lɨ́n|
| knife       | -∅       | wálɪ́       | -V        | wálɪ́.a |

**~~Table 29. Kuku singulatives and plural markers[^420]~~**

[^420]: Data from Cohen, *Aspects of the Grammar of Kukú.*

The underlying logic of the singulatives is evident; nouns that are considered inherently plural are unmarked, with individuals marked by suffix. Thus “Bari” is a nation and the singulative applies to a Bari person. The suffixes are all allomorphs of a basic *-VT* form, except for the additional nasal, which is either a person marker or the nasal also occurring in the plural. Plural suffixes can be reduced to a dental, a velar, a nasal and an underspecified vowel. The only unusual feature is the *-sɪʔ* suffix, which may be innovative.

### South Nilotic

There are two published reconstructions of South Nilotic.[^421] Rottland includes a substantial comparative wordlist as well as discussions of number marking. Tucker & Bryan discuss number marking with respect to Pokot and Nandi-Kipsigis. Based on their illustration of Pokot, **Table 30** extracts a sample of singular/plural pairings in Pokot, which illustrate singulatives in *-V(V)N* and *-tV* and plural in *-kV.* *-V(V)* suffixes are also common, but it is unclear how many are allomorphs and how many are distinct roots.

[^421]: Ehret, *Southern Nilotic History*; Rottland, *Die südnilotischen Sprachen.*

| Gloss       | Affix     | [sg]({sc})           |  Affix    | [pl]({sc})   |
| :---        | :---      |  :---         | :---      | :---  |
| the calf    | -Tv       | mɔ̀ɔ̀ɣ.tâ       | -V        | mòóɣ.eeʔ |
| the duiker  | -Tv       | cèptǐrkìc.tä́  | -kV       | cèptǐrkìc.kä̂ |
| the flea    | -VN + -Tv | kə̀mə̀tyàán.tɛ́ɛ́ | -kV       | kəmə́t.kä̂ |
| the spear   | -Tv       | ŋɔ̀t.ə́t        | -V, -V(V) | ŋät.w.éè |
| the lover   | -VN + -Tv | cä̀míín.téè    | -V        | cä̀m.í |
| the barred door | -V    | mä̀rä̀n.èéʔ     | -kV       | mä̀rä̂n.kä̂ |

**~~Table 30. Examples of Pokot number marking[^422]~~**

[^422]: Data from Tucker & Bryan, *Noun Classification in Kalenjin: Päkot*; Tucker & Bryan, *Noun Classification in Kalenjin: Nandi-Kipsigis.*

Pokot shows evidence for an original singulative *-V(V)N,* which has been resuffixed with *-tV(V).*

The number system of Endo, another language of the Markweeta (Marakwet) group, is described by Zwarts. Endo has a wide range of singulative suffixes shown in **Table 31**, although once allomorphy is considered, they can probably be reduced to a rather simpler set. Zwarts argues that plurals constitute the unmarked set.

| Gloss       | Affix       | [sg]({sc})           | [pl]({sc})   |
| :---        | :---        |  :---         | :---      |
| cloud       | -tV         | pool.ta       | pool |
| woman       | -ka         | kāār.kā       | kāār |
| grasshopper | -wa         | taalim.wa     | taalim |
| cedar       | -wa         | tārāāk.wā     | taraak |
| patch of grass | -wa + -Vn | sīūs.wāān    | sūūs |
| medicine    | -wa + -Vn   | saakit.yaan   | saakit |
| European    |  -Vn        | chūmp.īīn     | chumpa |
| shoe        | -V          | kwēēr.ā       | kwēēr |

**~~Table 31. Endo singulative suffixes[^t30]~~**

[^t30]: Data adapted from Zwarts, “Number in Endo-Marakwet.”

Underlyingly, therefore. Endo has the singulatives *-V(V)N, -tV, -V, -kV,* and an unmarked plural. Despite the surface differences, the West Nilotic system in these two examples is broadly similar.

## Synthesis

A feature of East Sudanic, and indeed Nilo-Saharan more generally, is extensive allomorphy. Each affix appears under several guises, often reflecting the stem to which is suffixed. **Table 32** shows the typical allomorphs of East Sudanic nominal affixes:

| Affix | Interpretation | Typical allomorphs |
| :---  | :---           | :---               |
| -T    | dentals        | /t/, /ʈ/, /d/, /ɖ/ |
| -K    | velars         | /k/, /g/           |
| -N    | nasals         | /n/, /ŋ/, /ɲ/      |
| -S    | fricatives     | /s/, /ʃ/, /ʤ/      |
| -V    | non-central vowels  | /i/, /u/      |
| -A    | central vowels  | /a/               |

**~~Table 32: Allomorphs of East Sudanic nominal affixes~~**

**Table 33** shows the presence or absence of individual affixes in each branch, together with affix-stacking and gemination, as well as the table which supports this analysis.

| Branch      | -T   | -K   | -N   | -V   | -S   | Affix stacking | Gemination | Reference |
| :---        | :--- | :--- | :--- | :--- | :--- | :---           | :---       | :---      |
| Nubian      | +    | –    | +    | –    | –    | +              | –          | Table 9, 10 |
| Nara        | +    | +    | –    | +    | +    | –              | +          | Table 13 |
| Nyima       | –    | ?    | –    | –    | –    | –              | –          | Table 15, 16 |
| Taman       | +    | +    | +    | +    | –    | –              | –          | Table 17 |
| Surmic      | +    | +    | +    | +    | +    | –              | –          | Table 19 |
| E Jebel     | +    | +    | +    | +    | –    | +              | –          | Table 20 |
| Temein      | +    | +    | +    | +    | +    | +              | –          | Table 22, 23, 24 |
| Daju        | +    | +    | +    | +    | +    | +              | –          | Table 26, 27 |
| W Nilotic   | +    | +    | +    | +    | –    | +              | –          | Table 28 |
| E Nilotic   | +    | +    | +    | +    | +    | +              | +          | Table 29 |
| S Nilotic   | +    | +    | +    | +    | –    | +              | –          | Table 30, 31 |


**~~Table 33. East Sudanic nominal affixes and associated~~**

The resultant pattern is not perfect but still indicative for the structure of East Sudanic. The number-marking suffixes form complete sets in En languages, with *-S* attested only in Nara. This implies that all five affixes were present in proto-East Sudanic but were preferentially lost in the Ek languages. Affix-stacking, though present in Nubian, is otherwise absent in Ek languages but is likely to be a retention from proto-East Sudanic. Gemination is too sparsely distributed to draw any conclusions, but is plausibly an independent development of no classificatory significance.

# Internal Structure of East Sudanic

The evidence presented points to a common inheritance in East Sudanic number marking strategies. The distribution of affix-stacking and complete affix sets suggest that apart from common lexemes, Ek languages are characterized by a common loss of these characters. In the light of this, **Figure 1** presents a revised internal classification of East Sudanic, grouping together the Ek languages as Northern East Sudanic, but leaving the others as independent branches.

![Proposed internal structure of East Sudanic](../static/images/classification2.png "Proposed internal structure of East Sudanic")

**~~Figure 1. Proposed internal structure of East Sudanic[^fig1]~~**

[^fig1]: Cf. Rilly, *Le méroïtique et sa famille linguistique,* 208.

It seems plausible that further results should be attainable from a deeper examination of the lexicon, since the effect of affix accretion and reanalysis obscures cognacy of roots.

# East Sudanic within Nilo-Saharan

The attentive reader will have observed that many of the affixes identified in this paper have been attested outside the proposed East Sudanic. Indeed, the “t-k substratum” proposed by Tucker & Bryan is far more widespread. Particular candidates are Kuliak and Kadu, a subgroup sometimes excluded from Nilo-Saharan altogether. This section considers briefly the morphology of these two groups in relation to our understanding of East Sudanic.

I have explored this morphology in the Kadu languages while Gilley has looked into number-marking in Katcha in some detail.[^601] Typically, Kadu languages have a three-term system with a singulative in *-t* and plural in *-k* and *-N.* They also have case-marking, which is only sporadically attested in East Sudanic languages and cannot be reconstructed, as well as sex-gender, which is entirely absent. This suggests that the *-T, -K,* and *-N* affixes can be reconstructed further back in Nilo-Saharan, but the *-V* and *-S* are distinctive to East Sudanic. The gemination found in Nara and East Nilotic is not recorded in Kadu, but may not be reconstructible to proto-East Sudanic.

[^601]: Blench, "The Kadu Languages and Their Affiliation"; Gilley, "Katcha Noun Morphology.”

The Kuliak languages, a small group in northeast Uganda which includes Ik, So, and Nyangi, were originally included by Greenberg within East Sudanic, but have long been treated as an independent branch of Nilo-Saharan. However, their lexicon has been heavily impacted both by their immediate neighbors, the Karimojong, but also by Southern Nilotic in some past era. Moreover, Lamberti has noted striking resemblances to the East Cushitic languages.[^602] Heine presents an overview and reconstruction of Kuliak as it was known at the period.[^603] More recently, Carlin and Schrock have provided extensive documentation of Soo and Ik (Icétôd).[^604] Kuliak languages have three-term number marking, with singulative in *-T* and plurative in *-K, -N,* as well as allowing affix-stacking, but also have a striking nominal case-marking system not present in East Sudanic. There is no evidence for gemination.

[^602]: Lamberti, *Kuliak and Cushitic.*
[^603]: Heine, *The Kuliak Languages of Eastern Uganda.*
[^604]: Carlin, *The So language*;  Schrock, *The Ik Language.*

In conclusion, East Sudanic is characterized by a series of affixes, which have developed out of a smaller set which are also present in related branches of Nilo-Saharan. Unlike Kadu, there is no trace of gender and the case marking. Case marking is also characteristic of Kuliak languages, which only have a reduced affix set. These suggest that there is a higher node within Nilo-Saharan which included these three branches, but that the East Sudanic language developed specific morphological features (or perhaps lost them at the level of the proto-language). It is striking that the lexical unity of East Sudanic is not more apparent, given the conservatism of the number-marking system.

# Abbreviations

* A: any central vowel ±ATR;
* C: any consonant;
* I: any high front vowel ±ATR;
* K: velar consonant;
* N: any nasal consonant;
* [pl]({sc}): plural;
* S: any fricative consonant;
* [sg]({sc}): singular;
* T: any dental consonant;
* V: any vowel;
* X: any phoneme.

# Bibliography

Alamin Mubarak, Suzan. ![“An Initial Description of Laggori Noun Morphology and Noun Phrase.”](bib:4d36dc7a-e169-463e-919e-9a02d5190f6b) In *Insights into Nilo-Saharan Language, History and Culture: Proceedings of the 9th Nilo-Saharan Linguistics Colloquium, Institute of African and Asian Studies, University of Khartoum, 16–19 February 2004,* edited by Al-Amin Abu-Manga, Leoma Gilley & Anne Storch. Cologne: Rüdiger Köppe, 2006: pp. 9–24.

Aviles, Arthur J. ![*The Phonology and Morphology of the Dar Daju Daju Language.*](bib:881b818e-77c1-4714-99fe-90e38630f6a7) MA Thesis, University of North Dakota at Grand Forks, 2008.

Bell, Herman. !["Documentary Evidence on the Ḥarāza Nubian.”](bib:9926e196-3eea-4b7c-856c-6272d4386c75) *Sudan Notes and Records* 7 (1975): pp. 1–36.

Bender, Lionel M. *Comparative Omotic Lexicon.* Carbondale: SIU, 2003.

Bender, Lionel M. “Genetic Subgrouping of East Sudanic.” *Afrikanistische Arbeitspapiere* 45 (1996): pp. 139–150.  

Bender, Lionel M. ![“Proto-Koman Phonology and Lexicon.”](bib:5e5624d2-4ddf-433e-9443-87728622f911) *Africa and Ubersee* 66, no. 2 (1983): pp. 259–297.

Bender, Lionel M. “Roland Stevenson’s Nyimang and Dinik Lexicon.” *Afrikanistische Arbeitspapiere* 63 (2000): pp. 103–120.  

Bender, Lionel M. ![“The Genetic Position of Nilotic *i*: Independent Pronouns.”](bib:7ec18d82-c61b-403b-9522-1eed5a336149) In *"Mehr als nur Worte…": Afrikanistische Beiträge zum 65. Geburtstag von Franz Rottland,* edited by R. Voßen, A. Mietzner, and A. Meißner. Cologne: Rudiger Köppe, 2000: pp. 89–119.

Bender, Lionel M. ![“The Eastern Jebel languages of Sudan I: Phonology.”](bib:6ba516f-5db9-45bd-b029-1db9c11b10ca) *Afrika und Übersee* 80 (1997): pp. 189–215.

Bender, Lionel M. ![“The Eastern Jebel languages of Sudan II: Comparative Lexicon.”](bib:c4983e62-25c5-4525-92ba-aac795a8c4ee) *Afrika und Übersee* 81 (1998): pp. 39–64.

Bender, Lionel M. ![*The East Sudanic Languages: Lexicon and Phonology.*](bib:bb56d307-45e4-4d4d-bf53-92a4adf2743d) Carbondale: Southern Illinois University, 2005.

Bender, Lionel M. ![*The Nilo-Saharan Languages: A Comparative Essay.*](bib:1e3f37e3-f5d0-418e-81aa-03d77268a20d) 2nd edition. Munich: Lincom Europa, 1997.

Blench, Roger M. ![“Introduction to the Temein Languages.”](bib:06802bbc-af26-4acb-bf98-cc8c3d1133a6) In *Nuba Mountain Language Studies,* edited by Thilo C. Schadeberg and Roger M. Blench. Cologne: Rüdiger Köppe, 2013: pp. 485–500.

Blench, Roger M. ![“The Kadu Languages and Their Affiliation: Between Nilo-Saharan, Niger-Congo and Afro-Asiatic.”](bib:8a8ae1e0-6f4b-478a-a292-fd6247aacdbc) In *Insights into Nilo-Saharan Language, History and Culture: Proceedings of the 9th Nilo-Saharan Linguistics Colloquium, Institute of African and Asian Studies, University of Khartoum, 16–19 February 2004,* edited by Al-Amin Abu-Manga, Leoma Gilley, and Anne Storch. Cologne: Rüdiger Köppe, 2006: pp. 101–127.

Boyeldieu, Pascal. !["Dadjo-Sila.”](bib:38130fe4-3b9f-49ca-8a18-9e609ccd504f) In *La qualification dans les langues africaines,* edited by Holger Tröbs, Eva Rothmaler, and Kerstin Winkelmann. Cologne: Rüdiger Köppe Verlag, 2008: pp. 57–70.

Browne, Gerald M. ![*Old Nubian Dictionary.*](bib:d9505774-ee71-4ab7-b076-96f26507ca47) Leuven: Peeters, 1996.

Bryan, Margaret. ![“The T–K Languages: A New Substratum.”](bib:16560c89-8752-499a-880b-439171c31936) *Africa* 29, no. 1 (1959): pp. 1–21.

Carlin, Eithne. ![*The So language.*](bib:6aedb64a-5f61-44ed-b6bf-cbeb0901e167) Cologne: Universität zu Köln, 1993.

Cohen, Kevin B. ![*Aspects of the Grammar of Kukú.*](bib:3c23c969-072e-4412-ab56-f2ca274d1309) Munich: Lincom Europa, 2000.

Dawd, Abushush & R.J. Hayward. ![“Nara.”](bib:ee9aea12-b98d-4fe6-896c-480fff47552d) *Journal of the International Phonetic Association* 32, no. 2 (2002): pp. 249–255.

De Voogt, Alex ![“Dual Marking and Kinship Terms in Afitti.”](bib:1b02f408-997f-4a0b-adf3-37d6fbc6c96d) *Studies in Language* 35, no. 4 (2011): pp. 898–911. [doi]({sc}): [10.1075/sl.35.4.04dev](https://doi.org/10.1075/sl.35.4.04dev).

Dimmendaal, Gerrit J. ![“Differential Object Marking in Nilo-Saharan.”](bib:40cf1704-08f3-4734-aa6a-6e9aeb61f1fc) *Journal of African Languages and Linguistics* 31 (2011): pp. 13–46.

Dimmendaal, Gerrit J. ![*Historical Linguistics and the Comparative Study of African Languages.*](bib:16e531a8-a386-4b05-9cbb-3ecc8ea3fdc3) Amsterdam: John Benjamins Publishing, 2011.

Dimmendaal, Gerrit J. "Marked Nominative Systems in Eastern Sudanic and Their Historical Origin.” *Afrikanistik Online* 11, no. 3 (2014): pp. 1–23.

Dimmendaal, Gerrit J. ![“Number Marking and Noun Categorization in Nilo-Saharan Languages.”](bib:3d490619-8e8b-408f-aaea-5e32cf815750) *Anthropological Linguistics* 42, no. 2 (2000): pp. 214–261.

Edgar, John T. ![“First Steps toward Proto-Tama.”](bib:268893cf-14bb-47a1-8582-704ef9a019e3) In *Proceedings of the Fourth Nilo-Saharan Conference: Bayreuth Aug. 30–Sep. 2, 1989,* edited by M. Lionel Bender. Hamburg: Helmut Buske, 1991: pp. 111–131.

Ehret, Christopher. ![*A Historical-Comparative Reconstruction of Nilo-Saharan.*](bib:765e512b-31d3-48ab-afe6-70cc4d56f14c) Cologne: Rudiger Köppe, 2001.

Ehret, Christopher. ![*Southern Nilotic History: Linguistic Approaches to the Study of the Past.*](bib:525edf81-a450-43b3-a5bf-068b01618951) Evanston: Northwestern University Press, 1971.

Gilley, Leoma G. ![“Katcha Noun Morphology.”](bib:e31ac0b3-4fec-4bdc-89a8-d75c16c8ce96) In *Nuba Mountain Language Studies,* edited by Thilo C. Schadeberg & Roger M. Blench. Cologne: Rudiger Köppe, 2013: pp. 501–522.

Greenberg, Joseph H. ![“Nilo-Saharan Moveable-*k* as a Stage III Article (with a Penutian Typological Parallel).”](bib:82be6462-9a21-4d01-9641-3edcb9fc673c) *Journal of African Languages and Linguistics* 3, no. 2 (1981): pp. 105–112.

Greenberg, Joseph H. ![“Studies in African Linguistic Classification: V. The Eastern Sudanic Family.”](bib:f3ebbf56-bddc-4bf8-b477-bf366645218a) *Southwestern Journal of Anthropology* 6, no. 2 (1950): pp. 143–160.

Greenberg, Joseph H. ![*The Languages of Africa.*](bib:df1c2298-341c-4367-a9cf-37452f7e3068) The Hague: Mouton & Co, 1963.

Güldemann, Tom. “The Historical-Comparative Status of East Sudanic.” In *Proceedings of the 14th Nilo-Saharan Linguistics Colloquium,* edited by Roger M. Blench, Petra Weschenfelder, and Georg Ziegelmeyer. Cologne: Rüdiger Köppe, forthcoming.

Hayward, Richard J. ![“Observations on Tone in the Higir Dialect of Nara.”](bib:650d0541-6aff-4348-b9ab-b856acff6c1a) In *"Mehr als nur Worte…": Afrikanistische Beiträge zum 65. Geburtstag von Franz Rottland,* edited by R. Voßen, A. Mietzner, and A. Meißner. Cologne: Rudiger Köppe, 2000: pp. 247–267.

Heine, Bernd. ![*The Kuliak Languages of Eastern Uganda.*](bib:036e86e0-9fc8-4474-9f41-df1e76f76101) Nairobi: East African Publishing House, 1976.

Jakobi, Angelika & Ahmed Hamdan. !["Number Marking on Karko Nouns.”](bib:89da9411-5890-4217-84f7-0625fe225063) *Dotawo: A Journal of Nubian Studies* 2 (2015): pp. 271–289. [doi]({sc}): [10.5070/D62110017](https://doi.org/10.5070/D62110017).

Joseph, Clement Lopeyok et al. ![*Laarim Grammar Book.*](bib:ce21cf9b-3ab4-424a-a594-d2ca9f3f17d0) Juba: SIL-Sudan, 2012.

Kellermann, P. ![*Eine grammatische Skizze des Tama auf der Basis der Daten von R.C. Stevenson.*](bib:51bfe843-94b8-4b98-a36a-5bf82c56d294) MA thesis, Johann-Wolfgang-Goethe Universitat, Mainz, 2000.

Lamberti, Marcello. ![*Kuliak and Cushitic: A Comparative Study.*](bib:5e8f9f20-9cc9-4c4c-8592-a4370f20b335) Heidelberg: Carl Winter, 1988.

Norton, Russell. "Ama Verbs in Comparative Perspective.” *Dotawo: A Journal of Nubian Studies* 7 (2020): ![this issue](article:norton.md)

Norton, Russell. ![“Number in Ama Verbs.”](bib:1892def2-7fbf-46ac-88ad-8dbb288c7e5a) *Occasional Papers in the Study of Sudanese Languages* 10 (2012): pp. 75–94.

Rilly, Claude. ![*Le méroïtique et sa famille linguistique.*](bib:2ca95718-79e8-40cd-939a-5dd0e3bbd07e) Leuven: Peeters, 2009.

Rilly, Claude & Alex de Voogt. ![*The Meroitic Language and Writing System.*](bib:e0cd6ef3-8da7-4280-9bb4-6eda37b27e36) Cambridge: Cambridge University Press, 2012.

Ross, James S. *A Preliminary Attempt at the Reconstruction of Proto-East Sudanic Phonology and Lexicon.* MA Thesis, Southern Illinois University, 1990.  

Rottland, Franz. ![*Die südnilotischen Sprachen: Beschriebung, Vergleichung und Rekonstruktion.*](bib:4a552fb8-607a-4dc5-9d9a-c268075c2e87) Berlin: Dietrich Reimer, 1982.

Schrock, Terrill B. ![*The Ik Language: Dictionary and Grammar Sketch.*](bib:89bbefdc-de7b-48a1-abf8-f85dd2fea799) Berlin: Language Science Press, 2016.

Starostin, George. ![“Lexicostatistical Studies in East Sudanic I: On the Genetic Unity of Nubian-Nara-Tama.”](bib:5bcbb628-53d3-4fa0-95e4-170fbb54c03f) *Journal of Language Relationship* [*Вопросы языкового родства*] 15, no. 2 (2017): pp. 87–113.

Stevenson, Roland C. ![“A Survey of the Phonetics and Grammatical Structures of the Nuba Mountain Languages, with Particular Reference to Otoro, Katcha and Nyimaŋ.”](bib:b8411bbc-e923-4876-bc7e-cbe3773812ed) *Afrika und Übersee* 40 (1956): pp. 73–84, 93–115.

Stevenson, Roland C. ![“A Survey of the Phonetics and Grammatical Structures of the Nuba Mountain Languages, with Particular Reference to Otoro, Katcha and Nyimaŋ.”](bib:859327ba-fe96-4c70-ae84-d441abadb867) *Afrika und Übersee* 41 (1957): pp. 27–65, 117–152, 171–196.

Stirtz, Timothy M. ![*A Grammar of Gaahmg: A Nilo-Saharan Language of Sudan.*](bib:723db61e-8c66-4df7-8683-d4cdfa4598df) Utrecht: LOT, 2011.

Storch, Anne. ![*The Noun Morphology of Western Nilotic.*](bib:649b0f27-c8a1-4863-ad50-68a5a0462920) Cologne: Rudiger Köppe, 2005.

Thelwall, Robin A. ![“Birgid Vocabulary List and Its Links with Daju.”](bib:9ed84dac-bac2-4595-93ef-86cd0ea9b735) In *Gedenkschrift Gustav Nachtigal 1874–1974,* edited by E. Ganslmayr and H. Jungraithmayr, pp. 197–210. Bremen: Übersee Museum, 1977.

Trigger, Bruce G. “Meroitic and Eastern Sudanic: A Linguistic Relationship.” *Kush* 12 (1964): 188–194.  

Tucker, Archibald N. ![*The Eastern Sudanic Languages, Vol. I.*](bib:7ad9f6ea-c1ec-4621-a51e-9d73a754ccf8) Oxford: Oxford University Press, 1940.

Tucker, Archibald N. & Margaret A. Bryan. ![*Linguistic Analyses: The Non-Bantu Languages of North-Eastern Africa.*](bib:5f973a26-ff68-48ce-aed9-f4323f8df471) London: Oxford University Press.

Tucker, Archibald N. & Margaret A. Bryan. *Noun Classification in Kalenjin: Nandi-Kipsigis.* London: School of Oriental and African Studies, University of London, 1964.  

Tucker, Archibald N. & Margaret A. Bryan. *Noun Classification in Kalenjin: Päkot.* London: School of Oriental and African Studies, University of London, 1962.  

Tucker, Archibald N. & Margaret A. Bryan. ![*The Non-Bantu Languages of North-Eastern Africa.*](bib:ae657fb7-5b21-438d-8c18-04d0beca9e40) London: Oxford University Press, 1956.

Voßen, Rainer. ![*The Eastern Nilotes: Linguistic and Historical Reconstructions.*](bib:7c6c8b50-41ee-4bb0-af6f-2b0a36c276f5) Berlin: Dietrich Reimer, 1982.

Werner, Roland. ![*Tìdn-áal: A Study of Midob (Darfur-Nubian).*](bib:56735ece-24da-4960-9101-ba484f7e57f7) Berlin: Dietrich Reimer, 1993.

Yigezu, Moges & Gerrit J. Dimmendaal. ![“Notes on Baale.”](bib:36f35b75-5629-478b-b969-f806474f54a0) In *Surmic Languages and Cultures,* edited by Gerrit J. Dimmendaal and Marco Last. Cologne: Rüdiger Köppe, 1998: pp. 273–317.

Zwarts, Joost. ![“Number in Endo-Marakwet.”](bib:7e4e38f4-ed1f-4f6f-a45d-c283fe4474c6) In *Advances in Nilo-Saharan Linguistics: Proceedings of the 8th Nilo-Saharan Linguistics Colloquium, University of Hamburg, August 22–25, 2001,* edited by Mechthild Reh and Doris L. Payne. Cologne: Rüdiger Köppe, 2007: pp. 281–294.
