---
title: "Dotawo 7: Comparative Northern East Sudanic Linguistics"
authors: ["vincentwjvangervenoei.md"]
has_articles: ["rilly.md", "norton.md", "jakobi.md", "starostin.md", "blench.md"]
---

# Preface by the Editor

## A New Platform

Since its inception, the [Union for Nubian Studies](http://unionfornubianstudies.org/) has been committed to opening up Nubiological research to a wider audience and broadening access to source materials. *Dotawo: A Journal of Nubian Studies* was launched in 2014 as an open-access journal, with free access for both authors and readers. It has been hosted by [DigitalCommons@Fairfield](https://digitalcommons.fairfield.edu/djns/) of Fairfield University and since 2019 by University of California's [eScholarship](https://escholarship.org/uc/dotawo) platform.

Both digital platforms allowed *Dotawo* to grow, expanding its reach by means of the creation of persistent digital identifiers and membership of the [Directory of Open Access Journals](https://doaj.org/toc/2373-2571). The content of *Dotawo,* however, remained essentially tailored to human — rather than machine — readers because it was only available in PDF or printed form, and to privileged readers with access to institutional libraries because the references it included were often difficult to access for members of the public without such access, even though most if not all of this research was produced with the aid of public funds. This state of affairs presented a challenge in terms of the accessibility and discoverability of the journal as well as the long-term preservation and openness of the scholarship presented and referenced.

Starting with the present issue, *Dotawo* will design and publish its content via the [Sandpoints](https://git.sandpoints.org/UnionForNubianStudies/Dotawo) platform. *Dotawo* contributions are formatted in [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax, thus moving away from proprietary software such as Microsoft Word and Adobe InDesign. For collaboration and version-control we employ [Git](https://en.wikipedia.org/wiki/Git) rather than Google Drive or Dropbox. The online issue is created via [Gitea](https://gitea.io/en-us/) and [Hugo](https://gohugo.io/), which take the Markdown files from the Git repository and generate a static website from them. The result is a compact and fast website, which moreover can also be used offline. Also the typography of *Dotawo* is now based on open fonts. The journal is typeset in [Gentium](https://software.sil.org/gentium/), which is released under an [SIL Open Font License](http://scripts.sil.org/ofl). The PDF output is generated by [PagedJS](https://www.pagedjs.org/), and will continue to be hosted on the eScholarship platform, while the printed book will remain available through scholar-led open access press [punctum books](https://punctumbooks.com/imprints/dotawo/). In short, all of the software used in the creation of *Dotawo* is now open source. Although this process demands a certain amount of flexibility of the editors, it also shows that transitioning an open access journal to open infrastructure is not only possible but also feasible.


The plundering and destruction of the University of Khartoum by forces allied with the former dictator during the 2019 Sudanese Revolution[^8] has once again impressed upon us the precarity of the research environment in which many scholars of Nubia operate and thus the necessity and moral obligation of creating open and resistant scholarly infrastructures. To improve the long-term preservation of and access to the scholarship contained and referenced in *Dotawo*, all sources mentioned in contributions to the journal will henceforth be linked, as much as possible, to records deposited in a public library using the open infrastructure of [Memory of the World](https://www.memoryoftheworld.org/).[^10] This will allow for easy storage and dissemination of both content and context of the research presented in *Dotawo* to those scholars of Nubia — and there are many — who are not institutionally privileged, including many who live in the Global South.

A recent, bleak assessment by Richard Poynder of the goals set by the [Budapest Open Access Initiative (BOAI) Declaration](https://www.budapestopenaccessinitiative.org/read) in 2002, and the open access movement more broadly, states that "it now seems unlikely that the *affordability* and *equity* problems will be resolved, which will impact disproportionately negatively on those in the Global South”:[^5]

>OA advocates failed to anticipate — and then for too long ignored — how their advocacy was allowing legacy publishers to co-opt open access, and in ways that work as much against the goals of BOAI as for them. And they have often downplayed the negative consequences that OA policies and initiatives developed in the Global North will have for those in the Global South.[^6]

Furthermore, it appears that the turn toward open access in the scholarly communications landscape is increasingly facilitating the agendas of an oligopoly of for-profit data analytics companies. Perhaps realizing that "they've found something that is even more profitable than selling back to us academics the content that we have produced,”[^9] they venture ever further up the research stream, with every intent to colonize and canalize its entire flow.[^4] This poses a severe threat to the independence and quality of scholarly inquiry.[^7]

In the light of these troubling developments, the expansion from *Dotawo* as a "diamond" open access to a *common access* journal represents a strong reaffirmation of the call that the late Aaron Swartz succinctly formulated in his "Guerilla Open Access Manifesto":

>Those with access to these resources — students, librarians, scientists — you have been given a privilege. You get to feed at this banquet of knowledge while the rest of the world is locked out. But you need not — indeed, morally, you cannot — keep this privilege for yourselves. You have a duty to share it with the world.[^3]  

Swartz's is a call to action that transcends the limitations of the open access movement as construed by the BOAI Declaration by plainly affirming that knowledge is a common good. His call goes beyond open access, because it specifically targets materials that linger on a paper or silicon substrate in academic libraries and digital repositories without being accessible to "fair use.” The deposition of the references from *Dotawo* contributions in a public library is a first and limited attempt to offer a remedy, heeding the "Code of Best Practices in Fair Use" of the [Association of Research Libraries](https://www.arl.org/resources/code-of-best-practices-in-fair-use-designing-the-public-domain/), which approvingly cites the late Supreme Court Justice Brandeis that “the noblest of human productions — knowledge, truths ascertained, conceptions, and ideas — become, after voluntary communication to others, free as the air to common use.”[^1] This approach also dovetails the interpretation of "folk law" recently propounded by Kenneth Goldsmith, the founder of public library [Ubuweb](https://ubu.com/).[^2]

I strongly believe that it is in the interest of Nubian Studies and its stakeholders, especially scholars in adjunct or para-academic positions without access to institutional repositories, and the Nubian people who are actively denied knowledge of their own culture, to enable the *widest possible* dissemination of scholarship. In this enterprise, striving for common access and relying on open source software are merely a first step.

[^1]: *Int’l News Serv. v. Associated Press,* 248 U.S. 215, 250 (1918) (Brandeis, J., dissenting), cited in Anon., "Designing the Public Domain,” p. 1494.
[^2]: Goldsmith, *Duchamp Is My Lawyer.*
[^3]: Swartz, "Guerilla Open Access Manifesto.”
[^4]: See, e.g., Moore, "The Datafication in Transformative Agreements for Open Access Publishing.”
[^5]: Poynder, "Open access: 'Information wants to be free'?" p. 2.
[^6]: Ibid., p. 22.
[^7]: The reduction in agency of academics as a result of the implementation of open access schemes has been widely recognized. As Christopher Kelty put it succinctly: "OA has come to exist and scholarship is more available and more widely distributed than ever before. But, scholars now have less control, and have taken less responsibility for the means of production of scientific research, its circulation, and perhaps even the content of that science" ("Recursive Publics and Open Access,” p. 7). These problems are exacerbated in the Global South, as the financial models for OA funding developed in the Global North threaten local public infrastructures managed by academics (Aguado-López & Becerril-Garcia, "The Commercial Model of Academic Publishing Underscoring Plan S Weakens the Existing Open Access Ecosystem in Latin America").
[^8]: "Report: Large Parts of University of Khartoum Destroyed on June 3.”
[^9]: Bodó, "Own Nothing,” p. 23.
[^10]: A public library is defined as follows: "[A] public library is: free access to books for every member of society; library catalog; librarian" (Mars, Zarroug & Medak, "Public Library,” p. 85).

## About This Issue

The seventh issue of *Dotawo* is dedicated to Comparative Northern East Sudanic (NES) linguistics, offering new insights in the historical connections between the Nubian languages and other members of the NES family such as Nyima, Taman, Nara, and Meroitic. A special focus is placed on comparative morphology.

The Nilo-Saharan phylum was first proposed by Joseph Greenberg as a linguistic remainder grouping whose internal affiliations remained unclear.[^a1] The Nilo-Saharan phylum contained what Greenberg then called Chari-Nile languages, which in turn included the Eastern Sudanic family. The coherence of this larger linguistic grouping will be investigated in the contribution by Roger Blench, ["Morphological Evidence for the Coherence of East Sudanic.”](article:blench.md)

Within Eastern Sudanic,[^a12] there is a further subdivision between what Lionel Bender referred to as the Ek- and En-branch, based on the shape of the [1sg]({sc}) pronoun.[^a2] Bender's Ek-branch contains the Nubian language, Nara, as well as the Nyima and Taman languages. This group of languages is now commonly referred to as Northern East Sudanic.

Although the contours of NES are relatively well established, much of the details of its linguistic development and relations remain the subject of ongoing research and debate. There are three particular issues within NES linguistics to which the articles in the present issue make a contribution:

* The coherence of Nile Nubian
* The inclusion of Nyima
* The inclusion of Meroitic

### The Coherence of Nile Nubian

Robin Thelwall proposed that the apparent proximity between Nile Nubian languages Nobiin and Mattokki–Andaandi was not the result of their belonging to the same branch within the Nubian language family, but due to prolonged language contact.[^a4] In other words, he proposed that there was no such thing as "Nile Nubian.” This proposal was further developed by Marianne Bechhaus-Gerst using lexicostatistical methods.[^a5]

Based on comparative NES phonology, Claude Rilly concluded on the contrary that Nobiin and Mattokki–Andaandi were closely related, and that the divergence between the two in terms of vocabulary was due to the influence of a substrate language underneath Nobiin.[^a6] Rilly's arguments are supported independently by lexicostatistical evidence presented by George Starostin in his contribution ["Restoring 'Nile Nubian': How to Balance Lexicostatistics and Etymology in Historical Research on Nubian Languages.”](article:starostin.md) Angelika Jakobi's ["Nubian Verb Extensions and Some Nyima Correspondences”](article:jakobi.md) provides further morphological evidence for the coherence of Nile Nubian.[^a10]

### The Inclusion of Nyima

Although Bender, Rilly, and Dimmendaal include the Nyima languages within NES,[^a7] these are excluded by Christopher Ehret in his *Historical-Comparative Reconstruction of Nilo-Saharan.*[^a8] Rejecting Ehret's proposition, Russell Norton's contribution ["Ama Verbs in Comparative Perspective”](article:norton.md) provides morphological evidence for inclusion of Nyima in NES. This is reinforced by several correspondences discussed in Jakobi's contribution between Nubian and Nyima.

### The Inclusion of Meroitic

Finally, the inclusion of Meroitic in NES has long been a point of contention owing to our fragmentary comprehension of the language.[^a9] In this respect, the work of Claude Rilly represents an enormous leap forward in our understanding, which can now with relatively strong certainty be classified as Nilo-Saharan, in particular Northern East Sudanic.[^a11] His contribution ["Personal Markers and Verbal Number in Meroitic”](article:rilly.md) provides for the first time a systematic overview of person marking in Meroitic, no doubt opening up further avenues in comparative Northern East Sudanic linguistics.

[^a1]: Greenberg, *The Languages of Africa,* p. 130.
[^a2]: Bender, *The East Sudanic Languages,* p. 1.
[^a4]: Thelwall, "Linguistic Aspects of a Greater Nubian History,” pp. 47–48.
[^a5]: See, in particular, Bechhaus-Gerst, "'Nile Nubian' Reconsidered.”
[^a6]: Rilly, *Le méroïtique et sa famille linguistique,* pp. 274–288.
[^a7]: Bender, *The East Sudanic Languages,* p. 1; Rilly, *Le méroïtique et sa famille linguistique,* pp. 181–183; Dimmendaal, "Nilo-Saharan,” p. 593.
[^a8]: Ehret, *A Historical-Comparative Reconstruction of Nilo-Saharan,* p. 88. Ehret refers to NES as "Astaboran.”
[^a9]: See, for an overview, Rilly, *Le méroïtique et sa famille linguistique,* pp. 25–36.
[^a10]: Perhaps it is now time for [Glottolog](https://glottolog.org/resource/languoid/id/nubi1251) to update its entry on Nubian.
[^a11]: Dimmendaal, "Nilo-Saharan,” p. 593.
[^a12]: See, for a recent overview, Güldemann, "Historical Linguistics and Genealogical Language Classification in Africa,” pp. 299–309.




# Bibliography

Aguado-López, Eduardo & Arianna Becerril-Garcia, "The Commercial Model of Academic Publishing Underscoring Plan S Weakens the Existing Open Access Ecosystem in Latin America.” *LSE Impact Blog,* May 20, 2020. https://blogs.lse.ac.uk/impactofsocialsciences/2020/05/20/the-commercial-model-of-academic-publishing-underscoring-plan-s-weakens-the-existing-open-access-ecosystem-in-latin-america/.

Anon. !["Designing the Public Domain.”](bib:4e7383bf-d59e-4884-a5d7-7bed70d71290) *Harvard Law Review* 122, no. 5 (2009): pp. 1489–1510.

Bechhaus-Gerst, Marianne. !["‘Nile-Nubianʼ Recon­sidered.”](bib:c17c58a0-0137-4db8-9f52-5d40e2acffa4) In *Topics in Nilo-Saharan Linguistics,* edited by M. Lio­nel Be­n­der. Ham­burg: Helmut Buske, 1989: pp. 85–96.

Bender, Lionel M. ![*The East Sudanic Languages: Lexicon and Phonology.*](bib:451c9cbd-baec-4d48-a568-aee6736ae290) Carbondale: Southern Illinois University, 2005.

Bodó, Balázs. !["Own Nothing.”](bib:2bb209af-f602-4d9f-9e85-64bf680a9661) In *Guerrilla Open Access,* ed. Memory of the World. Coventry: Post Office Press, Rope Press, and Memory of the World, 2018: pp. 16–24.

Dimmendaal, Gerrit J. ![“Nilo-Saharan.”](bib:5776b1b1-022a-45c0-9560-bdc8859dd74b) In *The Oxford Handbook of Derivational Morphology,* edited by Rochelle Lieber & Pavol Štekauer. Oxford: Oxford University Press, 2014: pp. 591–607.

Ehret, Christopher. ![*A Historical-Comparative Reconstruction of Nilo-Saharan.*](bib:cf0fc6eb-0e34-4dee-8902-c553e8aaa0ee) Cologne: Rudiger Köppe, 2001.

Goldsmith, Kenneth. ![*Duchamp Is My Lawyer: The Polemics, Pragmatics, and Poetics of Ubuweb.*](bib:5a73dbe3-2192-4496-9574-8d6a84cc71b3) New York: Columbia University Press, 2020.

Greenberg, Joseph H. ![*The Languages of Africa.*](bib:a107ca3b-6b11-49b2-bed3-9b246c811eec) The Hague: Mouton & Co, 1963.

Güldemann, Tom. !["Historical Linguistics and Genealogical Language Classification in Africa.”](bib:e5dbfdd7-93b5-4b66-9513-92403370363d) In *The Languages and Linguistics of Africa,* edited by Tom Güldemann. Berlin: Mouton de Gruyter, 2018: pp. 58–444.

Kelty, Christopher. !["Recursive Publics and Open Access.”](bib:8d18f630-9111-41ce-9d17-43e998ed9074) In *Guerrilla Open Access,* ed. Memory of the World. Coventry: Post Office Press, Rope Press, and Memory of the World, 2018: pp. 6–15.

Mars, Marcell, Manar Zarroug & Tomislav Medak. !["Public Library.”](bib:8bc32541-4d65-49a4-9dac-d8e109fd3ec6) In *Javna knjižnica – Public Library,* edited by Marcell Mars, Tomislav Medak, and WHW. Zagreb: WHW/Multimedijalni Institut, 2015: pp. 75–85.

Moore, Samuel. !["The Datafication in Transformative Agreements for Open Access Publishing.”](bib:63cfa334-1986-4073-bf4e-78c4a3a05fe6) July 3, 2020. https://www.samuelmoore.org/2020/07/03/the-datafication-in-transformative-agreements-for-open-access-publishing/

!["Report: Large Parts of University of Khartoum Destroyed on June 3.”](bib:c488659d-f9d3-4e24-a1cf-333e6f6cd6d3) *Dabanga,* August 7, 2019. https://www.dabangasudan.org/en/all-news/article/report-large-parts-of-university-of-khartoum-destroyed-on-june-3.

Rilly, Claude. ![*Le méroïtique et sa famille linguistique.*](bib:c191b60d-ae64-4eee-9c72-e71b7ae987b5) Leuven: Peeters, 2010.

Swartz, Aaron. !["Guerrilla Open Access Manifesto.”](bib:5c018728-5ffc-4a43-84c7-dae88e1b81d9) July 2008. https://archive.org/details/GuerillaOpenAccessManifesto/page/n1/mode/2up.

Thelwall, Robin. !["Linguistic Aspects of Greater Nubian History.”](bib:c1df2a82-ba52-4588-acda-1086e2dc3bcf) In *The Archaeological and Linguistic Reconstruction of African History,* edited by Christopher Ehret and Merrick Posnansky, pp. 39–56. Berkeley: University of California Press, 1982.
